package com.fastbee.rechargecard.mapper;

import java.util.List;
import com.fastbee.rechargecard.domain.NgUrbanMuRights;
import org.apache.ibatis.annotations.Mapper;

/**
 * 城镇亩均确权Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@Mapper
public interface NgUrbanMuRightsMapper
{
    /**
     * 查询城镇亩均确权
     *
     * @param muRightsId 城镇亩均确权主键
     * @return 城镇亩均确权
     */
    public NgUrbanMuRights selectNgUrbanMuRightsByMuRightsId(Long muRightsId);

    /**
     * 查询城镇亩均确权列表
     *
     * @param ngUrbanMuRights 城镇亩均确权
     * @return 城镇亩均确权集合
     */
    public List<NgUrbanMuRights> selectNgUrbanMuRightsList(NgUrbanMuRights ngUrbanMuRights);

    /**
     * 新增城镇亩均确权
     *
     * @param ngUrbanMuRights 城镇亩均确权
     * @return 结果
     */
    public int insertNgUrbanMuRights(NgUrbanMuRights ngUrbanMuRights);

    /**
     * 修改城镇亩均确权
     *
     * @param ngUrbanMuRights 城镇亩均确权
     * @return 结果
     */
    public int updateNgUrbanMuRights(NgUrbanMuRights ngUrbanMuRights);

    /**
     * 删除城镇亩均确权
     *
     * @param muRightsId 城镇亩均确权主键
     * @return 结果
     */
    public int deleteNgUrbanMuRightsByMuRightsId(Long muRightsId);

    /**
     * 批量删除城镇亩均确权
     *
     * @param muRightsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNgUrbanMuRightsByMuRightsIds(Long[] muRightsIds);
}
